@@ -53,7 +53,6 @@
 #include "XYList.h"
 #include "GraphPlotting.h"
 #include "InputMatrix.h"
-#include "ImagePlotting.h"
 #include "BoxPlotDecoder.h"
 #include "BoxPlotVisualiser.h"
 #include "SimplePolylineInput.h"
@@ -554,13 +553,7 @@ void FortranMagics::pgrib()
 
 void FortranMagics::pimage()
 {
-	actions();
-	if ( !action_ ) {
-		action_ = new VisualAction();
-		action_->data(new GribDecoder());
-	}
-	action_->visdef(new ImagePlotting());
-	action_ = 0;
+	MagLog::warning() <<" pimage is deprecated! Please use pcont."<< endl;
 }
 #else
 void FortranMagics::pgrib()
@@ -569,6 +562,7 @@ void FortranMagics::pgrib()
 
 void FortranMagics::pimage()
 {
+	MagLog::warning() <<" pimage is deprecated! Please use pcont."<< endl;
 }
 #endif
 
@@ -649,7 +643,7 @@ bool FortranMagics::geographical()
 	ParameterManager::get("subpage_map_projection", projection);
 	if ( magCompare(projection, "cartesian") ) return false;
 	if ( magCompare(projection, "taylor") ) return false;
-	if ( magCompare(projection, "tephigram") ) return false;
+	if ( magCompare(projection, "thermo") ) return false;
 	if ( magCompare(projection, "tephiinfo") ) return false;
 	return true;
 }
@@ -855,6 +849,7 @@ void FortranMagics::pline()
 }
 
 #include "WrepJSon.h"
+#include "EpsXmlInput.h"
 #include "EpsGraph.h"
 void  FortranMagics::wrepjson()
 {
@@ -869,6 +864,18 @@ void  FortranMagics::wrepjson()
 	action_->data(wrep);
 
 }
+void  FortranMagics::epsinput()
+{
+	actions();
+	action_ = new VisualAction();
+
+	EpsXmlInput* input = new EpsXmlInput();
+
+	top()->push_back(action_);
+	action_->data(input);
+}
+
+
 
 void  FortranMagics::epscloud()
 {
