@@ -877,6 +877,13 @@ static SimpleTranslator graph_y_missing_value("graph_y_missing_value", "y_missin
 static SimpleTranslator symbol_marker("symbol_marker", "symbol_marker_index");
 
 
+// Clean font parametermap_cities_font_
+static SimpleTranslator map_cities_font_name("map_cities_font_name", "map_cities_font");
+static SimpleTranslator eps_maximum_font_name("eps_maximum_font_name", "eps_maximum_font");
+static SimpleTranslator magnifier_text_font_name("magnifier_text_font_name", "magnifier_text_font");
+static SimpleTranslator symbol_text_font_name("symbol_text_font_name", "symbol_text_font");
+
+
 extern "C" {
 
 /* **************************************************************************
@@ -1170,6 +1177,10 @@ void pwrepjson_()
 {
 	magics_->wrepjson();
 }
+void pepsinput_()
+{
+	magics_->epsinput();
+}
 void pepscloud_()
 {
 	magics_->epscloud();
@@ -1243,6 +1254,7 @@ void mag_boxplot()  {pboxplot_();}
 void mag_taylor()  {ptaylor_();}
 void mag_tephi()  {ptephi_();}
 void mag_wrepjson()  { pwrepjson_(); }
+void mag_epsinput()  { pepsinput_(); }
 void mag_epscloud()  { pepscloud_(); }
 
 void mag_epsgraph()  	   { pepsgraph_(); }
@@ -1303,14 +1315,6 @@ void mag_setp(const char* name, void* value)
        ParameterManager::set("output_cairo_drawing_context", (CairoPtr)value); 
     }
 #endif
-#ifdef MAGICS_QT
-    if ( magCompare(n, "output_qt_widget") ) {
-       ParameterManager::set("output_qt_widget", (QWidgetPtr)value); 
-    }
-    if ( magCompare(n, "output_qt_scene") ) {
-       ParameterManager::set("output_qt_scene", (QGraphicsScenePtr)value); 
-    }	
-#endif
 }
 
 void mag_act(const char* a, const char* b, const char* c)
@@ -1555,7 +1559,7 @@ public:
 				if (magCompare(val, "position_list") ){
 					MagLog::warning() << "position_list is now using the user coordinates system and not cm" << endl;
 					MagLog::warning() << "please check your coordinates system" << endl;
-					ParameterManager::set(vertical_, "regular");
+
 				}
 				else
 					ParameterManager::set(horizontal_, val);
@@ -1565,7 +1569,7 @@ public:
 				if (magCompare(val, "position_list") ){
 					MagLog::warning() << "position_list is now using the user coordinates system and not cm" << endl;
 					MagLog::warning() << "please check your coordinates system" << endl;
-					ParameterManager::set(vertical_, "regular");
+
 				}
 				else
 					ParameterManager::set(vertical_, val);
