@@ -139,10 +139,15 @@ void PolarStereographicProjection::revert(const vector< std::pair<double, double
 {
 	assert(projection_);
 	out.reserve(in.size());
+
 	for ( vector< std::pair<double, double> >::const_iterator pt = in.begin();  pt != in.end(); ++pt) {
 		TeCoord2D texy = TeCoord2D(pt->first, pt->second);
 		TeCoord2D geo = projection_->PC2LL(texy);
-		out.push_back(make_pair(geo.x()*TeCRD, geo.y()*TeCRD));
+
+		if ( texy.y() > 0 && same(texy.x(), 0) )
+			out.push_back(make_pair(-180, geo.y()*TeCRD));
+		else
+			out.push_back(make_pair(geo.x()*TeCRD, geo.y()*TeCRD));
 	}
 }
 
@@ -213,6 +218,8 @@ void PolarStereographicProjection::init(double width, double height)
 
 		double stepx= (urx - llx)/100.;
 		double stepy= (ury - lly)/100.;
+		if (same(stepx, 0) )return;
+		if (same(stepy, 0) ) return;;
 		for (double x = llx; x <= urx; x += stepx )
 		{
 		   for (double y = lly; y <= ury; y += stepy )
@@ -734,7 +741,7 @@ void PolarStereographicProjection::centre(double width, double height)
 
 
 
-/*!
+/*!polar
  Read in the documentation:	
  For Polar Stereographic projections, the thinning factor is the distance, 
  in both X and Y directions, corresponding to the projected INPUT_FIELD_LONGITUDE_STEP ,
@@ -1003,5 +1010,11 @@ void PolarStereographicProjection::setDefinition(const string& json)
 
 
 }
+UserPoint PolarStereographicProjection::reference() const
+{
+	UserPoint ll = ( hemisphere_ ==  NORTH ) ? UserPoint(0, 60) : UserPoint(0, -60);
 
 
+	return ll;
+}
+
