@@ -111,6 +111,7 @@ public:
 	Transformation();
 	virtual ~Transformation();
 	virtual void init();
+    virtual void cleanPCEnveloppe();
 	void cleaninit();
 	enum CoordinateType {GeoType,XyType};
 	CoordinateType coordinateType() const {return coordinateType_;}	
@@ -125,8 +126,8 @@ public:
 		return object;
 	}
 	
-	virtual Polyline& getUserBoundingBox() const  { assert(false); }
-	virtual Polyline& getPCBoundingBox()   const  { assert(false); }
+	virtual Polyline& getUserBoundingBox() const  { assert(false);}
+	virtual Polyline& getPCBoundingBox()   const  { assert(false);}
 	
 	bool needTopAxis() const   { return topAxis_; }
 	void needTopAxis(bool top) { topAxis_ = top; }
@@ -187,7 +188,7 @@ public:
 	virtual void fill(double&, double&); // fill the space , can adapt the coordiantes to return the biggest area..
 	virtual void tile(double&, double&); // fill the space , can adapt the coordiantes to return the biggest area..
     virtual void forceNewArea(double, double, double, double, double&, double&);
-	
+	virtual UserPoint reference() const;
 	
 // Basic reprojection method! 
 	virtual PaperPoint operator()(const UserPoint& xy) const 
@@ -197,7 +198,7 @@ public:
 	virtual void fast_reproject(double& x, double& y) const
 			{ }
 
-	virtual double patchDistance(double) const { assert(false); }
+	virtual double patchDistance(double) const { assert(false);  return 0;}
 
 	virtual PaperPoint operator()(const PaperPoint& xy) const 
 		{ return xy; }
@@ -291,8 +292,9 @@ public:
 	
 	virtual double height() const { return getMaxX() - getMinX(); }
 	
-	virtual void thin(double, double, double, vector<UserPoint>&) const;
 
+	virtual void thin(double, PaperPoint&, vector<pair<double, double> >&) const;
+	virtual void thin(double, PaperPoint&, Matrix&, double) const;
 	virtual void getNewDefinition(const UserPoint&, const UserPoint&, string&) const
 		{ assert(false); }
 	virtual void setDefinition(const string&)
@@ -321,6 +323,7 @@ public:
 	   if (in(lon, lat) )
 		   out.push_back(UserPoint(lon, lat, val));
    }
+   double distance(UserPoint&, UserPoint&) const;
 protected:
 	virtual void print(ostream&) const;    
     
