@@ -52,7 +52,9 @@ public:
 	GribInterpretor() {}
 	virtual ~GribInterpretor() {}
 	virtual double XResolution(const GribDecoder&) const { return 0; }
-	virtual void raw(const GribDecoder&, const Transformation&, const string&, vector<UserPoint>&) const;
+	virtual void raw(const GribDecoder&, const Transformation&, const string&, map<double, map<double, CustomisedPoint*> >&) const;
+	virtual void raw(GribDecoder&, const Transformation&, vector<pair<double, vector<pair<double, CustomisedPoint*> > > >&, double&, double&) const;
+
 	virtual void interpretAsMatrix(const GribDecoder&, Matrix** matrix) const { *matrix = 0; }
 	virtual void interpretAsMatrix(const GribDecoder& grib, Matrix** matrix, const Transformation&) const
 		{ interpretAsMatrix(grib, matrix); }
@@ -60,12 +62,15 @@ public:
 
     virtual void interpret2D(double&, double&, double&, double&) const {}
     virtual void keepOriginal(bool) {}
+    virtual PaperPoint reference(const GribDecoder&, const Transformation&);
     virtual void interpretAsRaster(const GribDecoder&, RasterData&, const Transformation&) const {}
     virtual void scaling(const GribDecoder&, Matrix**) const;
     virtual void scaling(const GribDecoder& grib, double& scaling, double& offset) const;
     virtual void scaling(const GribDecoder& grib, double& scaling, double& offset, string& originalUnits, string& derivedUnits) const;
     void longitudesSanityCheck(double&, double&) const;
 
+    void interpolate(const GribDecoder& grib, Matrix& matrix) const;
+
     
 protected:
      //! Method to print string about this class on to a stream of type ostream (virtual).
