@@ -100,7 +100,6 @@ void SVGDriver::close()
 MAGICS_NO_EXPORT void SVGDriver::startPage() const
 {
 	debugOutput("Page - START");
-//	bool fixSize = fixSize_;
 	MFloat ratio = getRatio();
 	int   wid   = width_;
 
@@ -157,12 +156,12 @@ MAGICS_NO_EXPORT void SVGDriver::startPage() const
 	         << "inkscape:version=\"0.46\"\n"
 	         << "inkscape:output_extension=\"org.inkscape.output.svg.inkscape\"\n";
 	
-//	if(fixSize) pFile_<< "width=\""<<width<<"px\" height=\""<<height<<"px\" ";          ?????????????????????????????????????????????????????
+	if(fixSize_) pFile_<< "width=\""<<width<<"px\" height=\""<<height<<"px\" ";
 
 	pFile_ << "viewBox=\"0 0 "<<width+1<<" "<<height+1<<"\" xml:space=\"preserve\"";   
 //	 preserveAspectRatio=\"xMidYMid meet\"\n"
 //	 << " shape-rendering=\"optimizeSpeed\" text-rendering=\"optimizeSpeed\""
-	if(scripting_) pFile_<< " onload=\"OnLoadEvent(evt)\"";
+///	if(scripting_) pFile_<< " onload=\"OnLoadEvent(evt)\"";
 	pFile_<< ">\n<title>"<<title_<<"</title>\n";
 
 	if(!desc_.empty()) pFile_<< "<desc>"<<desc_<<"</desc>\n";
@@ -180,7 +179,7 @@ MAGICS_NO_EXPORT void SVGDriver::startPage() const
 	      << "\t<dc:coverage>Plot of meteorological data</dc:coverage>\n";
 	if(!meta_.empty()) pFile_<< "<!-- \n"<<meta_<<"\n-->\n";
 	pFile_<<"</cc:Work></rdf:RDF>\n</metadata>\n";
-
+/*
 	if(scripting_)
 	{
 		pFile_ << "<defs>\n"
@@ -189,6 +188,7 @@ MAGICS_NO_EXPORT void SVGDriver::startPage() const
 		       << " </clipPath>\n"
 		       << "</defs>\n";
 	}
+*/
 	pFile_<< "<g id=\"page\" transform=\"translate(0,"<<dimensionY_<<")\" vector-effect=\"non-scaling-stroke\">\n";
 }
 
@@ -206,7 +206,7 @@ MAGICS_NO_EXPORT void SVGDriver::endPage() const
 	debugOutput("Page - END");
 	closeGroup();
 	pFile_	<< "</g><!--ePage-->\n";   // needed for y-axis translation in beginning!
-
+/*
 	if(scripting_)
 	{
 		pFile_ << "<g id=\"menu\" visibility=\"visible\" fill=\"blue\" stroke=\"none\" font-size=\"10\" transform=\"translate("<<static_cast<int>(dimensionX_)-100<<" 5)\""
@@ -299,19 +299,19 @@ MAGICS_NO_EXPORT void SVGDriver::endPage() const
 			}
 			pFile_	<< "]]></script>\n";
 	}
-
+*/
 	pFile_ << "</svg>\n";
 	pFile_.close();
 
 	layers_.clear();
-/*
+
 	stringarray::iterator it    = svg_output_resource_list_.begin();
 	stringarray::iterator itend = svg_output_resource_list_.end();
 	for(; it != itend; it++)
 	{
 		printOutputName("SVG misc "+(*it));
 	}
-*/
+
 }
 
 /*!
@@ -381,6 +381,20 @@ MAGICS_NO_EXPORT void SVGDriver::unproject() const
 }
 
 
+MAGICS_NO_EXPORT string SVGDriver::buildLayerName(const Layer* layer, string type) const
+{
+  string s=layer->name();
+  if(s.empty()) return type;
+
+  char chars[] = "<>";
+  for (unsigned int i = 0; i < strlen(chars); ++i)
+  {
+    s.erase(std::remove(s.begin(), s.end(), chars[i]), s.end());
+  }
+  return s;
+}
+
+
 
 /*!
   \brief setup a new layer
@@ -392,10 +406,7 @@ MAGICS_NO_EXPORT void SVGDriver::unproject() const
 */
 MAGICS_NO_EXPORT void SVGDriver::redisplay(const StaticLayer& layer) const
 {
-	const string layName = layer.name();
-	currentLayer_ = (layName.empty()) ? "StaticLayer" : layName;
-//	currentTimeBegin_ = layer.kmlTimeBegin();
-//	currentTimeEnd_   = layer.kmlTimeEnd();
+	currentLayer_ = buildLayerName(&layer,string("StaticLayer"));
 
 	newLayer();
 	layer.visit(*this);
@@ -405,8 +416,7 @@ MAGICS_NO_EXPORT void SVGDriver::redisplay(const StaticLayer& layer) const
 
 MAGICS_NO_EXPORT void SVGDriver::redisplay(const StepLayer& layer) const
 {
-	const string layName = layer.name();
-	currentLayer_ = (layName.empty()) ? "Step" : layName;
+	currentLayer_ = buildLayerName(&layer,string("StepLayer"));
 
 	newLayer();
 	layer.visit(*this);
@@ -419,8 +429,7 @@ MAGICS_NO_EXPORT void SVGDriver::redisplay(const StepLayer& layer) const
  */
 MAGICS_NO_EXPORT void SVGDriver::redisplay(const NoDataLayer& layer) const
 {
-	const string layName = layer.name();
-	currentLayer_ = (layName.empty()) ? "Coast" : layName;
+	currentLayer_ = buildLayerName(&layer,string("Coastline"));
 
 	newLayer();
 	layer.visit(*this);
@@ -638,7 +647,11 @@ MAGICS_NO_EXPORT void SVGDriver::renderPolyline(const int n, MFloat *x, MFloat *
 MAGICS_NO_EXPORT void SVGDriver::renderPolyline2(const int n, MFloat* x, MFloat* y) const
 {
 	if(n != 2 || (currentColour_==Colour("none")) ) return;
-	pFile_ << "<path d=\"M"<<x[0]<< " " <<setY(y[0])<<"L"<< x[1] <<" "<< setY(y[1]) << "\"/>\n";
+	closeGroup();
+	const int r = static_cast<int>(currentColour_.red()  *255);
+	const int g = static_cast<int>(currentColour_.green()*255);
+	const int b = static_cast<int>(currentColour_.blue() *255);
+	pFile_ << "<path stroke=\"rgb("<<r<<","<<g<<","<<b<<")\" d=\"M"<<x[0]<< " " <<setY(y[0])<<"L"<< x[1] <<" "<< setY(y[1]) << "\"/>\n";
 }
 
 /*!
@@ -664,9 +677,8 @@ MAGICS_NO_EXPORT void SVGDriver::renderSimplePolygon(const int n, MFloat* x, MFl
 
 	ostringstream gStream;
 	if(currentColour_.alpha() < 1.) gStream << "fill-opacity=\""<<currentColour_.alpha()<<"\" stroke-opacity=\"0.01\" ";
-	gStream << "stroke=\"none\" fill-rule=\"evenodd\"";
+	gStream << "stroke=\"rgb("<<r<<","<<g<<","<<b<<")\" stroke-width=\"0.01\" fill-rule=\"evenodd\"";
 	openGroup(gStream.str());
-	//if(currentColour_.red()*currentColour_.green()*currentColour_.blue()<0) return;
 
 	int count = 1;
 	MFloat old_x = projectX(x[0]);
@@ -675,7 +687,7 @@ MAGICS_NO_EXPORT void SVGDriver::renderSimplePolygon(const int n, MFloat* x, MFl
 	double sumV = 0;
 	double sumH = 0;
 	ostringstream stream;
-	stream  <<" d=\"M"<<old_x<< " " << old_y;
+	stream  <<"d=\"M"<<old_x<< " " << old_y;
 
 	for(int is=1;is<n;is++)
 	{
@@ -710,9 +722,7 @@ MAGICS_NO_EXPORT void SVGDriver::renderSimplePolygon(const int n, MFloat* x, MFl
 	if     (fabs(sumV) > 0.001) {stream <<"v"<< sumV;}
 	else if(fabs(sumH) > 0.001) {stream <<"h"<< sumH;}
 
-//	if(!interactive_) stream  << "pointer-events=\"none\" ";
-
-	if(count > 3)
+	if(count > 2)
 	{
 		if(currentShading_==M_SH_DOT)
 		{
@@ -774,7 +784,7 @@ MAGICS_NO_EXPORT void SVGDriver::renderSimplePolygon(const int n, MFloat* x, MFl
 				<< r << ","
 				<< g << ","
 				<< b << ")\" ";
-//				<< "stroke=\"rgb("               // mde ECMWF logo blurry
+//				<< "stroke=\"rgb("               // made ECMWF logo blurry
 //				<< static_cast<int>(currentColour_.red()  *255) << ","
 //				<< static_cast<int>(currentColour_.green()*255) << ","
 //				<< static_cast<int>(currentColour_.blue() *255) << ")\" "
@@ -983,12 +993,15 @@ MAGICS_NO_EXPORT void SVGDriver::renderText(const Text& text) const
 		setNewColour(magfont.colour());
 		const MFloat dheight = magfont.size()*text_scale;
 		const std::set<string>& styles = magfont.styles();
-		string style = "";
-		if(styles.find("bold") != styles.end()) style = "bold";
-		if(styles.find("italic") != styles.end()) style += "italic";
-		if(style == "") style = "normal";
-		const string font   = magfont.name()+"_"+style;
-
+//		for (std::set<string>::iterator it=styles.begin(); it!=styles.end(); ++it)
+//		   std::cout << '_' << *it;
+//		string style = "";
+//		if(styles.find("bolditalic") != styles.end()) style = "bolditalic";
+//		else if(styles.find("bold") != styles.end()) style = "bold";
+//		else if(styles.find("italic") != styles.end()) style = "italic";
+		string style = "normal";
+//		cout << "___"<<style<<endl;
+		const string font = magfont.name()+"_"+style;
 		if (verticalAlign==MBASE )       vertical = dheight * .15;
 		else if (verticalAlign==MTOP)    vertical = dheight;
 		else if (verticalAlign==MHALF)   vertical = dheight * .5;
@@ -1014,8 +1027,9 @@ MAGICS_NO_EXPORT void SVGDriver::renderText(const Text& text) const
 		   {
 			ostringstream stream;
 			stream << "text-anchor=\""<<justification<< "\" font-size=\""<<dheight<<"cm\" font-family=\""<< ttf << "\" ";
-			if(styles.find("bold") != styles.end())   stream <<"font-weight=\"bold\" ";
-			if(styles.find("italic") != styles.end()) stream <<"font-style=\"italic\" ";
+			if(styles.find("bolditalic") != styles.end()) stream <<"font-weight=\"bold\" font-style=\"italic\" ";
+			else if(styles.find("bold")  != styles.end()) stream <<"font-weight=\"bold\" ";
+			else if(styles.find("italic")!= styles.end()) stream <<"font-style=\"italic\" ";
 			if(text.getAngle()!=0)
 				stream << "transform=\"rotate("<<text.getAngle()*57.29577951<<","<<xxx<<","<<yyy<<")\" ";
 			stream << "fill=\"rgb("<<static_cast<int>(currentColour_.red()*255)<<","<<static_cast<int>(currentColour_.green()*255)<<","
@@ -1035,8 +1049,9 @@ MAGICS_NO_EXPORT void SVGDriver::renderText(const Text& text) const
 		{
 		  pFile_ <<"<tspan "
 		      <<"font-size=\""<<dheight<<"cm\" font-family=\""<< ttf << "\" ";
-		  if(styles.find("bold") != styles.end())   pFile_ <<"font-weight=\"bold\" ";
-		  if(styles.find("italic") != styles.end()) pFile_ <<"font-style=\"italic\" ";
+		  if(styles.find("bolditalic") != styles.end()) pFile_ <<"font-weight=\"bold\" font-style=\"italic\" ";
+		  else if(styles.find("bold")  != styles.end()) pFile_ <<"font-weight=\"bold\" ";
+		  else if(styles.find("italic")!= styles.end()) pFile_ <<"font-style=\"italic\" ";
 		  pFile_ <<"fill=\"rgb("<<static_cast<int>(currentColour_.red()*255)<<","<<static_cast<int>(currentColour_.green()*255)<<","
 		      << static_cast<int>(currentColour_.blue()*255)<<")\""
 		      <<">"<<(*niceText).text()<<"</tspan>";
@@ -1468,7 +1483,7 @@ MAGICS_NO_EXPORT void SVGDriver::renderSymbols(const Symbol& symbol) const
 	  const MFloat y = projectY(symbol[0].y());
 
 	  string logofile;
-	  if(magCompare(location,"WWW")) logofile = "http://www.ecmwf.int/publications/manuals/magics/magplus/resources/ecmwf_logo.png";
+	  if(magCompare(location,"WWW")) logofile = "http://old.ecmwf.int/publications/manuals/magics/magplus/resources/ecmwf_logo.png";
 	  else if(magCompare(location,"LOCAL")) logofile = "ecmwf_logo.png";
 	  else logofile = getEnvVariable("MAGPLUS_HOME") + MAGPLUS_PATH_TO_SHARE_ + "ecmwf_logo.png";
 	  svg_output_resource_list_.push_back(logofile);
